@@ -1,34 +1,39 @@
 #' @templateVar class anova
 #' @template title_desc_tidy
-#' 
+#'
 #' @param x An `anova` objects, such as those created by [stats::anova()] or
 #'   [car::Anova()].
 #' @template param_unused_dots
-#' 
-#' @return A [tibble::tibble] with columns
-#' 
-#'   \item{term}{Term within the model, or "Residuals"}
-#'   \item{df}{Degrees of freedom used by this term in the model}
-#'   \item{sumsq}{Sum of squares explained by this term}
-#'   \item{meansq}{Mean of sum of squares among degrees of freedom}
-#'   \item{statistic}{F statistic}
-#'   \item{p.value}{P-value from F test}
-#'   
+#'
+#' @evalRd return_tidy(
+#'   "term",
+#'   "df",
+#'   "sumsq",
+#'   "meansq",
+#'   "statistic",
+#'   "p.value"
+#' )
+#'
 #' @details The `term` column of an ANOVA table can come with leading or
 #'   trailing whitespace, which this tidying method trims.
-#'   
+#'
 #' @examples
 #'
-#' a <- a <- aov(mpg ~ wt + qsec + disp, mtcars)
-#' tidy(a)
-#'
+#' a <- lm(mpg ~ wt + qsec + disp, mtcars)
+#' b <- lm(mpg ~ wt + qsec, mtcars)
+#' tidy(anova(a, b))
 #' @export
 #' @family anova tidiers
 #' @seealso [tidy()], [stats::anova()], [car::Anova()]
 tidy.anova <- function(x, ...) {
   # there are many possible column names that need to be transformed
   renamers <- c(
+    "AIC" = "AIC", # merMod
+    "BIC" = "BIC", # merMod
+    "deviance" = "deviance", # merMod
+    "logLik" = "logLik", # merMod
     "Df" = "df",
+    "Chi.Df" = "df",
     "Sum Sq" = "sumsq",
     "Mean Sq" = "meansq",
     "F value" = "statistic",
@@ -39,6 +44,7 @@ tidy.anova <- function(x, ...) {
     "F" = "statistic",
     "Chisq" = "statistic",
     "P(>|Chi|)" = "p.value",
+    "Pr(>|Chi|)" = "p.value",
     "Pr(>Chi)" = "p.value",
     "Pr..Chisq." = "p.value",
     "Pr..Chi." = "p.value",
@@ -47,13 +53,17 @@ tidy.anova <- function(x, ...) {
     "LR.Chisq" = "statistic",
     "LR Chisq" = "statistic",
     "edf" = "edf",
-    "Ref.df" = "ref.df"
+    "Ref.df" = "ref.df",
+    "loglik" = "logLik",
+    ".rownames" = "term"
   )
 
   names(renamers) <- make.names(names(renamers))
 
-  x <- fix_data_frame(x)
-  unknown_cols <- setdiff(colnames(x), c("term", names(renamers)))
+  ret <- as_augment_tibble(x)
+  colnames(ret) <- make.names(names(ret))
+
+  unknown_cols <- setdiff(colnames(ret), c("term", names(renamers)))
   if (length(unknown_cols) > 0) {
     warning(
       "The following column names in ANOVA output were not ",
@@ -61,8 +71,10 @@ tidy.anova <- function(x, ...) {
       paste(unknown_cols, collapse = ", ")
     )
   }
-  ret <- plyr::rename(x, renamers, warn_missing = FALSE)
-  if (!is.null(ret$term)) {
+
+  colnames(ret) <- dplyr::recode(colnames(ret), !!!renamers)
+
+  if ("term" %in% names(ret)) {
     # if rows had names, strip whitespace in them
     ret <- mutate(ret, term = stringr::str_trim(term))
   }
@@ -72,79 +84,107 @@ tidy.anova <- function(x, ...) {
 
 #' @templateVar class aov
 #' @template title_desc_tidy
-#' 
-#' @param x An `aov` objects, such as those created by [stats::aov()].
+#'
+#' @param x An `aov` object, such as those created by [stats::aov()].
 #' @template param_unused_dots
-#' 
-#' @return A [tibble::tibble] with columns
-#' 
-#'   \item{term}{Term within the model, or "Residuals"}
-#'   \item{df}{Degrees of freedom used by this term in the model}
-#'   \item{sumsq}{Sum of squares explained by this term}
-#'   \item{meansq}{Mean of sum of squares among degrees of freedom}
-#'   \item{statistic}{F statistic}
-#'   \item{p.value}{P-value from F test}
-#'   
-#' @details The `term` column of an ANOVA table can come with leading or
-#'   trailing whitespace, which this tidying method trims.
-#'   
+#'
+#' @inherit tidy.anova return details
+#'
 #' @examples
 #'
 #' a <- aov(mpg ~ wt + qsec + disp, mtcars)
 #' tidy(a)
-#'
 #' @export
 #' @family anova tidiers
 #' @seealso [tidy()], [stats::aov()]
 tidy.aov <- function(x, ...) {
-  s <- summary(x)
-  tidy.anova(s[[1]])
+  summary(x)[[1]] %>%
+    tibble::as_tibble(rownames = "term") %>%
+    dplyr::mutate("term" = stringr::str_trim(term)) %>%
+    rename2(
+      "df" = "Df",
+      "sumsq" = "Sum Sq",
+      "meansq" = "Mean Sq",
+      "statistic" = "F value",
+      "p.value" = "Pr(>F)"
+    )
 }
 
 
+#' @templateVar class lm
+#' @template title_desc_glance
+#'
+#' @inherit tidy.aov params examples
+#'
+#' @note
+#' Note that `tidy.aov()` now contains the numerator and denominator degrees of 
+#' freedom, which were included in the output of `glance.aov()` in some
+#' previous versions of the package.
+#'
+#' @evalRd return_glance(
+#'   "logLik",
+#'   "AIC",
+#'   "BIC",
+#'   "deviance",
+#'   "nobs"
+#' )
+#'
+#' @export
+#' @seealso [glance()]
+#' @family anova tidiers
+glance.aov <- function(x, ...) {
+  as_glance_tibble(
+    logLik = as.numeric(stats::logLik(x)),
+    AIC = stats::AIC(x),
+    BIC = stats::BIC(x),
+    deviance = stats::deviance(x),
+    nobs = stats::nobs(x),
+    na_types = "rrrri"
+  )
+  
+}
+
 #' @templateVar class aovlist
 #' @template title_desc_tidy
-#' 
+#'
 #' @param x An `aovlist` objects, such as those created by [stats::aov()].
 #' @template param_unused_dots
-#' 
-#' @return A [tibble::tibble] with columns
-#' 
-#'   \item{term}{Term within the model, or "Residuals"}
-#'   \item{df}{Degrees of freedom used by this term in the model}
-#'   \item{sumsq}{Sum of squares explained by this term}
-#'   \item{meansq}{Mean of sum of squares among degrees of freedom}
-#'   \item{statistic}{F statistic}
-#'   \item{p.value}{P-value from F test}
-#'   \item{stratum}{The error stratum}
-#'   
-#' @details The `term` column of an ANOVA table can come with leading or
-#'   trailing whitespace, which this tidying method trims.
-#'   
+#'
+#' @evalRd return_tidy(
+#'   "term",
+#'   "df",
+#'   "sumsq",
+#'   "meansq",
+#'   "statistic",
+#'   "p.value",
+#'   "stratum"
+#' )
+#'
+#' @inherit tidy.anova details
+#'
 #' @examples
 #'
 #' a <- aov(mpg ~ wt + qsec + Error(disp / am), mtcars)
 #' tidy(a)
-#'
 #' @export
 #' @family anova tidiers
 #' @seealso [tidy()], [stats::aov()]
 tidy.aovlist <- function(x, ...) {
-  
+
   # must filter out Intercept stratum since it has no dimensions
   if (names(x)[1L] == "(Intercept)") {
     x <- x[-1L]
   }
 
   ret <- map_df(x, tidy, .id = "stratum")
-  
+
   # get rid of leading and trailing whitespace in term and stratum columns
-  ret <- ret %>% 
+  ret <- ret %>%
     mutate(
       term = stringr::str_trim(term),
       stratum = stringr::str_trim(stratum)
     )
-  
+
   as_tibble(ret)
 }
 
@@ -158,41 +198,41 @@ tidy.aovlist <- function(x, ...) {
 #'   indicating which test statistic should be used. Defaults to "Pillai".
 #' @inheritDotParams stats::summary.manova
 #'
-#' @return A [tibble::tibble] with columns:
-#' 
-#'     \item{term}{Term in design}
-#'     \item{statistic}{Approximate F statistic}
-#'     \item{num.df}{Degrees of freedom}
-#'     \item{p.value}{P-value}
+#' @evalRd return_tidy(
+#'   "term",
+#'   "num.df",
+#'   "den.df",
+#'   "statistic",
+#'   "p.value",
+#'   pillai = "Pillai's trace.",
+#'   wilks = "Wilk's lambda.",
+#'   hl = "Hotelling-Lawley trace.",
+#'   roy = "Roy's greatest root."
+#' )
 #'
-#' Depending on which test statistic is specified, one of the following
-#' columns is also included:
-#' 
-#'     \item{pillai}{Pillai's trace}
-#'     \item{wilks}{Wilk's lambda}
-#'     \item{hl}{Hotelling-Lawley trace}
-#'     \item{roy}{Roy's greatest root}
+#'
+#' @details Depending on which test statistic is specified only one of `pillai`,
+#'   `wilks`, `hl` or `roy` is included.
 #'
 #' @examples
 #'
 #' npk2 <- within(npk, foo <- rnorm(24))
 #' m <- manova(cbind(yield, foo) ~ block + N * P * K, npk2)
-#' tidy(m) 
-#'
+#' tidy(m)
 #' @export
 #' @seealso [tidy()], [stats::summary.manova()]
 #' @family anova tidiers
 tidy.manova <- function(x, test = "Pillai", ...) {
-  
-  # TODO: use match.arg here
   test.pos <- pmatch(test, c(
     "Pillai", "Wilks",
     "Hotelling-Lawley", "Roy"
   ))
   test.name <- c("pillai", "wilks", "hl", "roy")[test.pos]
-  
-  nn <- c("df", test.name, "statistic", "num.df", "den.df", "p.value")
-  fix_data_frame(summary(x, test = test, ...)$stats, nn)
+
+  as_tidy_tibble(
+    summary(x, test = test, ...)$stats, 
+    new_names = c("df", test.name, "statistic", "num.df", "den.df", "p.value")
+  )
 }
 
 #' @templateVar class TukeyHSD
@@ -201,14 +241,15 @@ tidy.manova <- function(x, test = "Pillai", ...) {
 #' @param x A `TukeyHSD` object return from [stats::TukeyHSD()].
 #' @template param_unused_dots
 #'
-#' @return A [tibble::tibble] with one row per comparison and columns:
-#' 
-#'   \item{term}{Term for which levels are being compared}
-#'   \item{comparison}{Levels being compared, separated by -}
-#'   \item{estimate}{Estimate of difference}
-#'   \item{conf.low}{Low end of confidence interval of difference}
-#'   \item{conf.high}{High end of confidence interval of difference}
-#'   \item{adj.p.value}{P-value adjusted for multiple comparisons}
+#' @evalRd return_tidy(
+#'   "term",
+#'   "contrast",
+#'   "null.value",
+#'   "estimate",
+#'   "conf.low",
+#'   "conf.high",
+#'   "adj.p.value"
+#' )
 #'
 #' @examples
 #'
@@ -219,15 +260,21 @@ tidy.manova <- function(x, test = "Pillai", ...) {
 #' # may include comparisons on multiple terms
 #' fm2 <- aov(mpg ~ as.factor(gear) * as.factor(cyl), data = mtcars)
 #' tidy(TukeyHSD(fm2))
-#'
 #' @export
 #' @seealso [tidy()], [stats::TukeyHSD()]
 #' @family anova tidiers
 tidy.TukeyHSD <- function(x, ...) {
   purrr::map_df(x,
     function(e) {
-      nn <- c("estimate", "conf.low", "conf.high", "adj.p.value")
-      fix_data_frame(e, nn, "comparison")
-    }, .id = "term"
+      null.value <- rep(0, nrow(e))
+      e <- cbind(null.value, e)
+      as_tidy_tibble(
+        e, 
+        new_names = c("null.value", "estimate", "conf.low", 
+                      "conf.high", "adj.p.value"), 
+        new_column = "contrast"
+      )
+    },
+    .id = "term"
   )
 }
